@@ -75,6 +75,12 @@ def from_list_str(x: Any) -> List[str]:
     return x
 
 
+def from_list_int(x: Any) -> List[int]:
+    assert isinstance(x, list)
+    assert all(isinstance(item, int) for item in x)
+    return x
+
+
 def from_float(x: Any) -> float:
     assert isinstance(x, (float, int)) and not isinstance(x, bool)
     return float(x)
@@ -297,6 +303,8 @@ class ModelComponentsParam:
     """
     regressors: Optional[Dict[str, Any]] = None
     """For modeling regressors, see template for details"""
+    lagged_regressors: Optional[Dict[str, Any]] = None
+    """For modeling lagged regressors, see template for details"""
     seasonality: Optional[Dict[str, Any]] = None
     """For modeling seasonality, see template for details"""
     uncertainty: Optional[Dict[str, Any]] = None
@@ -315,6 +323,7 @@ class ModelComponentsParam:
             lambda x: from_list_dict_or_none(lambda x: x, x),
             from_none], obj.get("hyperparameter_override"))
         regressors = from_union([lambda x: from_dict(lambda x: x, x), from_none], obj.get("regressors"))
+        lagged_regressors = from_union([lambda x: from_dict(lambda x: x, x), from_none], obj.get("lagged_regressors"))
         seasonality = from_union([lambda x: from_dict(lambda x: x, x), from_none], obj.get("seasonality"))
         uncertainty = from_union([lambda x: from_dict(lambda x: x, x), from_none], obj.get("uncertainty"))
         return ModelComponentsParam(
@@ -325,6 +334,7 @@ class ModelComponentsParam:
             growth=growth,
             hyperparameter_override=hyperparameter_override,
             regressors=regressors,
+            lagged_regressors=lagged_regressors,
             seasonality=seasonality,
             uncertainty=uncertainty)
 
@@ -340,6 +350,7 @@ class ModelComponentsParam:
             lambda x: from_list_dict_or_none(lambda x: x, x),
             from_none], self.hyperparameter_override)
         result["regressors"] = from_union([lambda x: from_dict(lambda x: x, x), from_none], self.regressors)
+        result["lagged_regressors"] = from_union([lambda x: from_dict(lambda x: x, x), from_none], self.lagged_regressors)
         result["seasonality"] = from_union([lambda x: from_dict(lambda x: x, x), from_none], self.seasonality)
         result["uncertainty"] = from_union([lambda x: from_dict(lambda x: x, x), from_none], self.uncertainty)
         return result
@@ -368,6 +379,13 @@ class ForecastConfig:
     """Number of periods to forecast into the future. Must be > 0.
     If None, default is determined from input data frequency.
     """
+    forecast_one_by_one: Optional[Union[bool, int, List[int]]] = None
+    """The options to activate the forecast one-by-one algorithm.
+    See :class:`~greykite.sklearn.estimator.one_by_one_estimator.OneByOneEstimator`.
+    Can be boolean, int, of list of int.
+    If int, it has to be less than or equal to the forecast horizon.
+    If list of int, the sum has to be the forecast horizon.
+    """
     metadata_param: Optional[MetadataParam] = None
     """Information about the input data. See
     :class:`~greykite.framework.templates.autogen.forecast_config.MetadataParam`.
@@ -393,6 +411,7 @@ class ForecastConfig:
         evaluation_metric_param = from_union([EvaluationMetricParam.from_dict, from_none], obj.get("evaluation_metric_param"))
         evaluation_period_param = from_union([EvaluationPeriodParam.from_dict, from_none], obj.get("evaluation_period_param"))
         forecast_horizon = from_union([from_int, from_none], obj.get("forecast_horizon"))
+        forecast_one_by_one = from_union([from_int, from_bool, from_none, from_list_int], obj.get("forecast_one_by_one"))
         metadata_param = from_union([MetadataParam.from_dict, from_none], obj.get("metadata_param"))
         if not isinstance(obj.get("model_components_param"), list):
             obj["model_components_param"] = [obj.get("model_components_param")]
@@ -406,6 +425,7 @@ class ForecastConfig:
             evaluation_metric_param=evaluation_metric_param,
             evaluation_period_param=evaluation_period_param,
             forecast_horizon=forecast_horizon,
+            forecast_one_by_one=forecast_one_by_one,
             metadata_param=metadata_param,
             model_components_param=model_components_param,
             model_template=model_template)
@@ -417,6 +437,7 @@ class ForecastConfig:
         result["evaluation_metric_param"] = from_union([lambda x: to_class(EvaluationMetricParam, x), from_none], self.evaluation_metric_param)
         result["evaluation_period_param"] = from_union([lambda x: to_class(EvaluationPeriodParam, x), from_none], self.evaluation_period_param)
         result["forecast_horizon"] = from_union([from_int, from_none], self.forecast_horizon)
+        result["forecast_one_by_one"] = from_union([from_int, from_bool, from_none, from_list_int], self.forecast_one_by_one)
         result["metadata_param"] = from_union([lambda x: to_class(MetadataParam, x), from_none], self.metadata_param)
         if not isinstance(self.model_components_param, list):
             self.model_components_param = [self.model_components_param]
