@@ -4,7 +4,6 @@ from typing import Optional
 
 import numpy as np
 import pandas as pd
-import plotly
 from sklearn.model_selection import RandomizedSearchCV
 from sklearn.pipeline import Pipeline
 
@@ -310,9 +309,9 @@ def check_forecast_pipeline_result(
             result.grid_search,
             score_func=score_func,
             score_func_greater_is_better=greater_is_better))
-        plotly.offline.plot(ts.plot())
-        plotly.offline.plot(result.backtest.plot())
-        plotly.offline.plot(result.forecast.plot())
+        ts.plot().write_html("test_ts_plot.html")
+        result.backtest.plot().write_html("test_backtest_plot.html")
+        result.forecast.plot().write_html("test_forecast_plot.html")
 
 
 def assert_basic_pipeline_equal(actual: Pipeline, expected: Pipeline):
@@ -450,6 +449,7 @@ def mock_pipeline(
         # model
         pipeline=None,
         regressor_cols=None,
+        lagged_regressor_cols=None,
         estimator=SimpleSilverkiteEstimator(),
         hyperparameter_grid=None,
         hyperparameter_budget=None,
@@ -488,6 +488,7 @@ def mock_pipeline(
         "anomaly_info": anomaly_info,
         "pipeline": pipeline,
         "regressor_cols": regressor_cols,
+        "lagged_regressor_cols": lagged_regressor_cols,
         "estimator": estimator,
         "hyperparameter_grid": hyperparameter_grid,
         "hyperparameter_budget": hyperparameter_budget,
