@@ -1,3 +1,5 @@
+import math
+import os
 import warnings
 
 import cvxpy as cp
@@ -8,10 +10,14 @@ from scipy.linalg import sqrtm
 from sklearn.exceptions import NotFittedError
 
 from greykite.algo.reconcile.convex.reconcile_forecasts import ReconcileAdditiveForecasts
+from greykite.algo.reconcile.convex.reconcile_forecasts import TraceInfo
 from greykite.algo.reconcile.convex.reconcile_forecasts import apply_method_defaults
+from greykite.algo.reconcile.convex.reconcile_forecasts import evaluation_plot
 from greykite.algo.reconcile.convex.reconcile_forecasts import get_fit_params
 from greykite.algo.reconcile.convex.reconcile_forecasts import get_weight_matrix
 from greykite.algo.reconcile.hierarchical_relationship import HierarchicalRelationship
+from greykite.common.constants import TIME_COL
+from greykite.common.data_loader import DataLoader
 from greykite.common.evaluation import mean_absolute_percent_error
 from greykite.common.evaluation import median_absolute_percent_error
 from greykite.common.evaluation import root_mean_squared_error
@@ -60,40 +66,39 @@ def test_get_weight_matrix():
         weights=None,
         n_forecasts=3,
         name="weight_bias",
-        weight_auto=None)
+        default_weights={})
     assert_equal(np.eye(3), wmat)
 
-    # weights is 'auto', weight_auto is None
+    # weights is string
+    default_weights = {
+        "identity": np.ones((3, 3)),
+        "custom": np.random.rand(3, 3),
+    }
     wmat = get_weight_matrix(
-        weights="auto",
+        weights="custom",
         n_forecasts=3,
         name="weight_bias",
-        weight_auto=None)
-    assert_equal(np.eye(3), wmat)
-
-    # weights is 'auto', weight_auto is not None
-    wmat = get_weight_matrix(
-        weights="auto",
-        n_forecasts=3,
-        name="weight_bias",
-        weight_auto=np.ones((3, 3)))
-    assert_equal(np.ones((3, 3)), wmat)
+        default_weights=default_weights)
+    target_norm = math.sqrt(3)
+    expected_wmat = default_weights["custom"] * target_norm / np.linalg.norm(default_weights["custom"])
+    assert_equal(expected_wmat, wmat)
 
     # weights is a list
     wmat = get_weight_matrix(
         weights=[1, 2, 3],
         n_forecasts=3,
         name="weight_bias",
-        weight_auto=None)
-    assert_equal(np.diag([1, 2, 3]), wmat)
+        default_weights={})
+    expected_wmat = np.diag([1, 2, 3]) * target_norm / np.linalg.norm(np.diag([1, 2, 3]))
+    assert_equal(expected_wmat, wmat)
 
     # weights is an array
     wmat = get_weight_matrix(
         weights=np.array([1, 2, 3]),
         n_forecasts=3,
         name="weight_bias",
-        weight_auto=None)
-    assert_equal(np.diag([1, 2, 3]), wmat)
+        default_weights={})
+    assert_equal(expected_wmat, wmat)
 
     # exception
     with pytest.raises(ValueError, match="Expected square matrix with size 10, but `weight_bias` "
@@ -102,12 +107,22 @@ def test_get_weight_matrix():
             weights=np.array([1, 2, 3]),
             n_forecasts=10,  # doesn't match len(weights)
             name="weight_bias",
-            weight_auto=None)
+            default_weights={})
+
+    # weights is string, no default
+    with pytest.raises(ValueError, match="The requested weight 'dummy' for `weight_bias` is not found. "
+                                         "Must be one of \['custom'\]"):  # noqa: W605
+        wmat = get_weight_matrix(
+            weights="dummy",
+            n_forecasts=3,
+            name="weight_bias",
+            default_weights={"custom": np.ones((3, 3))})
+        assert_equal(np.eye(3), wmat)
 
 
 def test_get_fit_params():
     """Tests get_fit_params"""
-    params = get_fit_params(method=None)
+    params = get_fit_params(method="custom")
     assert params == {}
 
     params = get_fit_params(method="bottom_up")
@@ -124,7 +139,7 @@ def test_get_fit_params():
     assert params["covariance"] == "sample"
 
     with pytest.raises(ValueError, match="`method` 'unknown' is not recognized. "
-                                         "Must be one of 'bottom_up', 'ols', 'mint_sample' or None"):
+                                         "Must be one of 'bottom_up', 'ols', 'mint_sample', 'custom'"):
         get_fit_params(method="unknown")
 
 
@@ -155,7 +170,7 @@ def test_apply_method_defaults():
         "params": {"method": "mint_sample"},
     })
 
-    # `method` is not None
+    # `method` != "custom"
     new_fit_func = apply_method_defaults(dummy_fit_func)
     params = {
         "method": "mint_sample",
@@ -175,10 +190,10 @@ def test_apply_method_defaults():
     })
     assert params["covariance"] == "sample"  # overwritten by the default
 
-    # `method` is None
+    # `method` == "custom"
     new_fit_func = apply_method_defaults(dummy_fit_func)
     params = {
-        "method": None,
+        "method": "custom",
         "covariance": "identity",
         "verbose": True}
     result = new_fit_func(
@@ -193,22 +208,76 @@ def test_apply_method_defaults():
         "params": params,
     })
 
-    # `method` is not provided
-    new_fit_func = apply_method_defaults(dummy_fit_func)
-    params = {
-        "covariance": "identity",
-        "verbose": True}
-    result = new_fit_func(
-        self="self",
-        forecasts="forecasts",
-        actuals="actuals",
-        **params)
-    assert_equal(result, {
-        "self": "self",
-        "forecasts": "forecasts",
-        "actuals": "actuals",
-        "params": params,
-    })
+
+def test_trace_info(data):
+    """Tests TraceInfo initialization"""
+    trace = TraceInfo(
+        df=data["forecasts"],
+        color="blue",
+        name="forecast",
+        legendgroup=None)
+    assert_equal(trace.df, data["forecasts"])
+
+
+def test_evaluation_plot(data):
+    """Tests evaluation_plot"""
+    forecasts = data["forecasts"]
+    actuals = data["actuals"]
+    num_timeseries = forecasts.shape[1]
+    x = forecasts.index
+
+    with pytest.raises(ValueError, match="There must be at least one trace to plot."):
+        evaluation_plot(x=x, traces=[])
+
+    with pytest.raises(ValueError, match="``x`` length must match ``df`` length for all traces."):
+        evaluation_plot(x=x[:10], traces=[TraceInfo(df=actuals)])
+
+    with pytest.raises(ValueError, match="Column names must be identical in all traces."):
+        f = forecasts.copy()
+        f.columns = list("abcd")
+        traces = [
+            TraceInfo(df=f),
+            TraceInfo(df=actuals)
+        ]
+        evaluation_plot(x=x, traces=traces)
+
+    traces = [
+        TraceInfo(df=forecasts),  # uses default (None) for other attributes
+        TraceInfo(df=actuals, color="blue", name="actuals", legendgroup="a")
+    ]
+    # num_cols [1, num_timeseries] is is valid
+    for num_cols in range(num_timeseries):
+        evaluation_plot(x=x, traces=traces, num_cols=num_cols+1)
+
+    # num_cols outside this range is invalid
+    with pytest.raises(ValueError) as record:
+        evaluation_plot(x=x, traces=traces, num_cols=0)
+        assert f"`num_cols` should be between 1 and 4 (the number of columns), found 0." in record[0].message.args[0]
+
+    with pytest.raises(ValueError) as record:
+        evaluation_plot(x=x, traces=traces, num_cols=num_timeseries+1)
+        assert f"`num_cols` should be between 1 and 4 (the number of columns), found 5." in record[0].message.args[0]
+
+    # plot can be customized
+    ylabel = "ylabel"
+    title = "title_text"
+    hline = True
+    fig = evaluation_plot(x=x, traces=traces, ylabel=ylabel, title=title, hline=hline)
+    assert len(fig.data) == num_timeseries*(hline+len(traces))  # 4 plots, each with zero and two traces
+    assert fig.data[0].name == "zero"  # horizontal line
+    assert fig.data[1].name == "c1"  # name is the timeseries name
+    assert fig.data[1].legendgroup is None
+    assert fig.data[2].legendgroup == "a"
+    assert fig.data[2].line.color == "blue"
+    assert fig.data[2].name == "c1-actuals"  # "actuals" is appended ot the name
+    assert fig.layout.title.text == title
+    assert fig.layout.title.x == 0.5
+    assert fig.layout.yaxis.title.text == ylabel
+    assert fig.layout.yaxis4.title.text == ylabel
+
+    hline = False
+    fig = evaluation_plot(x=x, traces=traces, ylabel=ylabel, title=title, hline=hline)
+    assert len(fig.data) == num_timeseries*(hline+len(traces))  # horizontal lines are removed
 
 
 def test_raf_init():
@@ -218,6 +287,7 @@ def test_raf_init():
     assert raf.covariance is None
     assert raf.covariance is None
     assert raf.constraint_violation is None
+    assert raf.figures is None
     assert raf.lam_adj == 0.0
     assert not raf.unbiased
 
@@ -306,15 +376,27 @@ def test_raf_form_objective():
     Ya = 100 * np.random.rand(m, n)
     Ya = tree.bottom_up_transform @ Ya  # makes values consistent
     Yf = Ya + np.random.rand(m, n)  # adds forecast error
+    Yf[0] = Ya[0]  # makes one forecast have zero error
     transform_matrix = np.eye(m) + np.random.rand(m, m)
     # derived variables
-    weight_auto = np.diag(np.nanmedian(np.abs(Ya - Yf) / np.abs(Ya), axis=1))
-    weight_auto = weight_auto * np.sqrt(m) / np.linalg.norm(weight_auto)
-    cov = np.cov(Ya - Yf)
+    err = np.nanmedian(np.abs(Ya - Yf) / np.abs(Ya), axis=1)
+    weight_err = np.diag(err)
+    weight_err *= np.sqrt(m) / np.linalg.norm(weight_err)
 
-    # covariance is None, "auto" weight_bias
+    inv_err = err.copy()
+    inv_err[np.where(inv_err == 0)] = np.min(inv_err[np.where(inv_err > 0)])  # Sets zeros to minimum value above zero
+    weight_inverr = np.diag(1 / inv_err)
+    weight_inverr *= np.sqrt(m) / np.linalg.norm(weight_inverr)
+
+    residuals = Ya - Yf
+    cov = residuals @ residuals.T / residuals.shape[1]
+
+    # covariance is None, default weights "MedAPE", "InverseMedAPE"
     raf = ReconcileAdditiveForecasts()
-    raf.weight_bias = "auto"
+    raf.weight_adj = np.repeat(2, m)  # will be normalized, equivalent to np.repeat(1, m)
+    raf.weight_bias = "InverseMedAPE"
+    raf.weight_train = "MedAPE"
+    raf.weight_var = "InverseMedAPE"
     obj = raf._form_objective(
         Yf=Yf,
         Ya=Ya,
@@ -322,90 +404,80 @@ def test_raf_form_objective():
         covariance=None)
     assert_equal(raf.objective_weights, {
         "weight_adj": np.eye(m),
-        "weight_bias": weight_auto,
-        "weight_coef": np.ones((m, m)),
-        "weight_train": np.eye(m),
-        "weight_var": np.eye(m),
+        "weight_bias": weight_inverr,
+        "weight_train": weight_err,
+        "weight_var": weight_inverr,
         "covariance": None})
     assert raf.objective_fn(None) is None
-    assert raf.objective_fn(transform_matrix)["var"] == 0.0  # variance term is 0.0
+    assert raf.objective_fn(transform_matrix)["var"] == 0.0  # variance=0.0 when covariance is None
     assert obj.is_dcp()
-    assert len(obj.constants()) == 25  # lams, weights, other constants
+    assert len(obj.constants()) == 20  # lams, weights, other constants
 
-    # "identity" covariance, "auto" weight_coef, weight_adj
+    # "identity" covariance
     raf = ReconcileAdditiveForecasts()
-    raf.weight_adj = "auto"
-    raf.weight_coef = "auto"
+    raf.weight_adj = "MedAPE"
     obj = raf._form_objective(
         Yf=Yf,
         Ya=Ya,
         transform_variable=transform_variable,
         covariance="identity")
     assert_equal(raf.objective_weights, {
-        "weight_adj": weight_auto,
+        "weight_adj": weight_err,
         "weight_bias": np.eye(m),
-        "weight_coef": np.ones((m, m)) - np.eye(m),
         "weight_train": np.eye(m),
         "weight_var": np.eye(m),
         "covariance": np.eye(m)})
     assert raf.objective_fn(transform_matrix) == {
         "adj": 0.0,  # all the self.lam_* are 0.0
         "bias": 0.0,
-        "coef": 0.0,
         "train": 0.0,
         "var": 0.0,
         "total": 0.0}
-    assert len(obj.constants()) == 28  # now includes covariance term
+    assert len(obj.constants()) == 23  # now includes covariance term
 
     # "sample" covariance
     raf = ReconcileAdditiveForecasts()
     raf.lam_adj = 1.1
     raf.lam_bias = 2.2
-    raf.lam_coef = 3.3
-    raf.lam_train = 4.4
-    raf.lam_var = 5.5
+    raf.lam_train = 3.3
+    raf.lam_var = 4.4
     obj = raf._form_objective(
         Yf=Yf,
         Ya=Ya,
         transform_variable=transform_variable,
         covariance="sample")
     assert obj.is_dcp()
-    assert len(obj.constants()) == 28
+    assert len(obj.constants()) == 23
     assert obj.constants()[0].value == raf.lam_adj
     assert obj.constants()[1].value == raf.lam_bias
-    assert obj.constants()[2].value == raf.lam_coef
-    assert obj.constants()[3].value == raf.lam_train
-    assert obj.constants()[4].value == raf.lam_var
-    assert_equal(obj.constants()[5].value, raf.objective_weights["weight_adj"])
+    assert obj.constants()[2].value == raf.lam_train
+    assert obj.constants()[3].value == raf.lam_var
+    assert_equal(obj.constants()[4].value, raf.objective_weights["weight_adj"])
+    assert_equal(obj.constants()[5].value, Yf)
     assert_equal(obj.constants()[6].value, Yf)
-    assert_equal(obj.constants()[7].value, Yf)
     assert_equal(raf.objective_weights, {
         "weight_adj": np.eye(m),
         "weight_bias": np.eye(m),
-        "weight_coef": np.ones((m, m)),
         "weight_train": np.eye(m),
         "weight_var": np.eye(m),
         "covariance": cov})
     # Tests objective_fn value
     expected_adj = raf.lam_adj * np.linalg.norm(raf.objective_weights["weight_adj"] @ (transform_matrix @ Yf - Yf))**2 / np.size(Yf)
     expected_bias = raf.lam_bias * np.linalg.norm(raf.objective_weights["weight_bias"] @ (transform_matrix @ Ya - Ya))**2 / np.size(Ya)
-    expected_coef = raf.lam_coef * np.linalg.norm(np.multiply(raf.objective_weights["weight_coef"], transform_matrix - np.eye(m)))**2 / (m**2)
     expected_train = raf.lam_train * np.linalg.norm(raf.objective_weights["weight_train"] @ (transform_matrix @ Yf - Ya))**2 / np.size(Yf)
     expected_var = raf.lam_var * np.linalg.norm(raf.objective_weights["weight_var"] @ transform_matrix @ sqrtm(cov))**2 / m
     assert_equal(raf.objective_fn(transform_matrix), {
         "adj": expected_adj,
         "bias": expected_bias,
-        "coef": expected_coef,
         "train": expected_train,
         "var": expected_var,
-        "total": expected_adj + expected_bias + expected_coef + expected_train + expected_var})
+        "total": expected_adj + expected_bias + expected_train + expected_var})
     assert_equal(raf.objective_fn(transform_matrix, forecast_matrix=Yf*2, actual_matrix=Ya*2), {
         "adj": 4*expected_adj,
         "bias": 4*expected_bias,
-        "coef": expected_coef,
         "train": 4*expected_train,
         "var": expected_var,
-        "total": 4*expected_adj + 4*expected_bias + expected_coef + 4*expected_train + expected_var})
+        "total": 4*expected_adj + 4*expected_bias + 4*expected_train + expected_var})
     # Tests equivalence of variance formula with trace
     var_alternative = raf.lam_var * np.trace(transform_matrix @ cov @ transform_matrix.T) / m
     assert_equal(var_alternative, raf.objective_fn(transform_matrix)["var"])
@@ -512,7 +584,7 @@ def test_raf_fit(data):
     assert raf.upper_bound is None  # overridden by "mint_sample"
     assert_equal(raf.forecasts, reorder_columns(forecasts, order_dict=order_dict))
     residuals = Ya / Ya.mean() - Yf / Ya.mean()
-    covariance = np.cov(residuals)
+    covariance = residuals @ residuals.T / residuals.shape[1]
     assert_equal(raf.objective_weights["covariance"], covariance)
     assert raf.prob is not None
     assert raf.is_optimization_solution
@@ -532,11 +604,40 @@ def test_raf_fit(data):
             order_dict=order_dict,
             unbiased=False,
             covariance="sample",
-            lam_var=1.0)
+            lam_adj=3.0,
+            lam_var=2.0)
         assert raf.transform_matrix is not None
+        # checks custom values
+        assert not raf.unbiased
+        assert raf.covariance == "sample"
+        assert raf.lam_adj == 3.0
+        assert raf.lam_var == 2.0
+        # checks default values
+        assert raf.method == "custom"
+        assert raf.lower_bound is None
+        assert raf.upper_bound is None
+        assert raf.lam_bias == 1.0
+        assert raf.lam_train == 1.0
+        assert raf.weight_adj is None
+        assert raf.weight_bias is None
+        assert raf.weight_train is None
+        assert raf.weight_var is None
+        # all the terms are here
+        assert_equal(raf.objective_fn_val, {
+            "adj": 0.2871105061424012,
+            "bias": 0.03758041936764179,
+            "train": 0.08568482849991804,
+            "var": 0.019903924375932396,
+            "total": 0.4302796783858934
+        })
 
-    # Tests custom covariance matrix, unbiased=Tue, all terms in objective
+    # Tests custom covariance matrix, unbiased=True, all terms in objective
     covariance = 20 * np.random.randn(m, m)
+    weight_err = np.diag(np.nanmedian(np.abs(Ya - Yf) / np.abs(Ya), axis=1))
+    weight_err *= np.sqrt(m) / np.linalg.norm(weight_err)
+    weight_inverr = np.diag(1 / np.diag(weight_err))
+    weight_inverr *= np.sqrt(m) / np.linalg.norm(weight_inverr)
+
     raf = ReconcileAdditiveForecasts()
     raf.fit(
         forecasts=forecasts,
@@ -548,12 +649,11 @@ def test_raf_fit(data):
         unbiased=True,
         lam_adj=1.0,
         lam_bias=1.0,
-        lam_coef=1.0,
         lam_train=1.0,
         lam_var=1.0,
         covariance=covariance,
-        weight_bias="auto",
-        weight_coef="auto",
+        weight_adj=None,
+        weight_bias="MedAPE",
         weight_train=list(range(m)),
         weight_var=list(range(m, 0, -1)),
         reltol=1e-7,  # solver params
@@ -561,8 +661,14 @@ def test_raf_fit(data):
         feastol=1e-7)
     scaled_covariance = covariance / Ya.mean()**2
     assert_equal(raf.objective_weights["covariance"], scaled_covariance)
-    assert_equal(raf.objective_weights["weight_train"], np.diag(list(range(m))))
-    assert_equal(raf.objective_weights["weight_var"], np.diag(list(range(m, 0, -1))))
+    assert_equal(raf.objective_weights["weight_adj"], np.eye(m))
+    assert_equal(raf.objective_weights["weight_bias"], weight_err)
+    exp_weight_train = np.diag(list(range(m)))
+    exp_weight_train = exp_weight_train * math.sqrt(m) / np.linalg.norm(exp_weight_train)
+    assert_equal(raf.objective_weights["weight_train"], exp_weight_train)
+    exp_weight_var = np.diag(list(range(m, 0, -1)))
+    exp_weight_var = exp_weight_var * math.sqrt(m) / np.linalg.norm(exp_weight_var)
+    assert_equal(raf.objective_weights["weight_var"], exp_weight_var)
     assert raf.prob is not None
     assert_equal(raf.transform_variable.value, raf.transform_matrix)
     # satisfies constraints
@@ -570,6 +676,22 @@ def test_raf_fit(data):
     assert_equal(raf.transform_matrix @ Ya, Ya)
     assert raf.objective_fn_val["bias"] < 1e-10
 
+    # Tests weight "MedAPE", "InverseMedAPE"
+    raf = ReconcileAdditiveForecasts()
+    raf.fit(
+        forecasts=forecasts,
+        actuals=actuals,
+        levels=levels,
+        order_dict=order_dict,
+        weight_adj="InverseMedAPE",
+        weight_bias="InverseMedAPE",
+        weight_train="MedAPE",
+        weight_var="MedAPE")
+    assert_equal(raf.objective_weights["weight_adj"], weight_inverr)
+    assert_equal(raf.objective_weights["weight_bias"], weight_inverr)
+    assert_equal(raf.objective_weights["weight_train"], weight_err)
+    assert_equal(raf.objective_weights["weight_var"], weight_err)
+
     # Tests bottom up forecast
     raf = ReconcileAdditiveForecasts()
     raf.fit(
@@ -590,8 +712,6 @@ def test_raf_fit(data):
             actuals=actuals,
             levels=levels,
             order_dict=order_dict,
-            unbiased=True,
-            lam_adj=1.0,
             lower_bound=3.0,
             upper_bound=3.0)
         assert_equal(raf.transform_matrix, raf.tree.bottom_up_transform)
@@ -611,8 +731,7 @@ def test_raf_fit(data):
             constraint_matrix=constraint_matrix,
             order_dict=order_dict,
             unbiased=False,
-            lam_adj=1.0,
-            lam_bias=1.0)
+        )
         assert_equal(raf.constraint_matrix, constraint_matrix)
         assert np.linalg.norm(raf.constraint_matrix @ raf.transform_matrix) < 1e-5
 
@@ -626,8 +745,6 @@ def test_raf_fit(data):
             actuals=actuals,
             constraint_matrix=constraint_matrix,
             order_dict=order_dict,
-            unbiased=True,
-            lam_adj=1.0,
             lower_bound=3.0,
             upper_bound=3.0)
         assert raf.transform_matrix is None
@@ -706,18 +823,19 @@ def test_raf_evaluate(data):
 
     # Tests `evaluate` on training set
     raf.evaluate(is_train=True)
+    assert len(raf.figures) == 3
     assert raf.constraint_violation["actual"] < 1e-5
     assert raf.constraint_violation["adjusted"] < 1e-5
     assert raf.constraint_violation["forecast"] > 1e-5
     assert list(raf.evaluation_df.columns) == [
-        "RMSE % change",
         "MAPE pp change",
         "MedAPE pp change",
+        "RMSE % change",
         "Base MAPE",
-        "Base MedAPE",
-        "Base RMSE",
         "Adjusted MAPE",
+        "Base MedAPE",
         "Adjusted MedAPE",
+        "Base RMSE",
         "Adjusted RMSE",
     ]
     assert_equal(
@@ -732,9 +850,9 @@ def test_raf_evaluate(data):
         raf.evaluation_df["MedAPE pp change"],
         raf.evaluation_df["Adjusted MedAPE"] - raf.evaluation_df["Base MedAPE"],
         check_names=False)
-    assert list(raf.evaluation_df["RMSE % change"] > 0) == [True, False, False, False]
-    assert list(raf.evaluation_df["MAPE pp change"] > 0) == [True, False, False, False]
-    assert list(raf.evaluation_df["MedAPE pp change"] > 0) == [True, False, False, False]
+    assert list(raf.evaluation_df["RMSE % change"] > 0) == [False, False, False, False]
+    assert list(raf.evaluation_df["MAPE pp change"] > 0) == [False, False, False, False]
+    assert list(raf.evaluation_df["MedAPE pp change"] > 0) == [False, False, False, False]
     assert_equal(
         mean_absolute_percent_error(raf.actuals["root"], raf.adjusted_forecasts["root"]),
         raf.evaluation_df.loc["root", "Adjusted MAPE"])
@@ -753,6 +871,7 @@ def test_raf_evaluate(data):
     assert_equal(
         root_mean_squared_error(raf.actuals["c1"], raf.forecasts["c1"]),
         raf.evaluation_df.loc["c1", "Base RMSE"])
+    evaluation_df = raf.evaluation_df
 
     # Changing the parameters affects the evaluation results
     raf = ReconcileAdditiveForecasts()
@@ -766,19 +885,45 @@ def test_raf_evaluate(data):
         unbiased=True,
         lam_adj=0.0,
         lam_bias=0.0,
-        lam_coef=0.0,
         lam_train=1.0,
         lam_var=0.0,
         covariance=None,
         weight_bias=None,
-        weight_coef=None,
         weight_train=[2, 1, 1, 1],
         weight_var=None)
     # Tests `evaluate` on training set
-    raf.evaluate(is_train=True)
-    assert list(raf.evaluation_df["RMSE % change"] > 0) == [False, False, False, False]  # All have improved
+    raf.evaluate(is_train=True, plot=False, plot_num_cols=2)
+    assert list(raf.evaluation_df["RMSE % change"] > 0) == [False, False, False, False]
     assert list(raf.evaluation_df["MAPE pp change"] > 0) == [False, False, False, False]
     assert list(raf.evaluation_df["MedAPE pp change"] > 0) == [False, False, False, False]
+    assert not evaluation_df.equals(raf.evaluation_df)
+    assert len(raf.figures) == 3
+    fig = raf.figures["base_adj"]
+    assert len(fig.data) == 8
+    assert fig.data[0].name == "root-base"  # plots use reordered columns
+    assert fig.data[1].name == "root-adjusted"
+    assert fig.data[2].name == "c1-base"
+    assert fig.data[1].legendgroup == "adjusted"
+    assert fig.data[1].line.color == "#ff893a"
+    assert fig.layout.title.text == "Base vs Adjusted Forecast"
+    assert fig.layout.title.x == 0.5
+    assert fig.layout.yaxis.title.text == "value"
+    fig = raf.figures["adj_size"]
+    assert len(fig.data) == 8
+    assert fig.data[0].name == "zero"
+    assert fig.layout.title.text == "Adjustment Size (%)"
+    assert fig.layout.title.x == 0.5
+    assert fig.layout.yaxis.title.text == "% adj."
+    fig = raf.figures["error"]
+    assert len(fig.data) == 12
+    assert fig.data[0].name == "zero"
+    assert fig.layout.title.text == "Forecast Error (%)"
+    assert fig.layout.title.x == 0.5
+    assert fig.layout.yaxis.title.text == "% error"
+    # Checks layout with plot_num_cols=2
+    assert fig.layout.xaxis.domain != fig.layout.xaxis2.domain
+    assert fig.layout.xaxis.domain == fig.layout.xaxis3.domain
+    assert fig.layout.xaxis2.domain == fig.layout.xaxis4.domain
 
     # Tests `evaluate` on test set
     actuals_test = actuals + 2.0
@@ -816,8 +961,9 @@ def test_raf_evaluate(data):
             order_dict=order_dict,
             method="bottom_up"),
         evaluate_kwargs=dict(
-            plot=True,
-            ipython_display=True)
+            ipython_display=True,
+            plot=False,
+            plot_num_cols=2),
     )
     assert_equal(raf.evaluation_df, raf2.evaluation_df)
     assert_equal(raf.adjusted_forecasts, raf2.adjusted_forecasts)
@@ -828,8 +974,72 @@ def test_raf_evaluate(data):
         raf2.transform_evaluate(
             forecasts_test=forecasts_test,
             actuals_test=actuals_test,
-            plot=True,
+            plot=False,
+            plot_num_cols=2,
             ipython_display=True)
+        assert len(raf2.figures_test) == 3
+        assert raf2.figures != raf2.figures_test
+
     assert_equal(
         root_mean_squared_error(raf2.actuals_test["c1"], raf2.forecasts_test["c1"]),
         raf2.evaluation_df_test.loc["c1", "Base RMSE"])
+
+
+def test_raf_ols_mint():
+    """Verify that output for "ols" and "mint_sample" match expected output from R."""
+    # Expected results from R `hts` package
+    data_dir = os.path.join(os.path.dirname(os.path.realpath(__file__)), "data")
+    expected_ols = pd.read_csv(os.path.join(data_dir, "expected_ols.csv")).drop(columns=TIME_COL)
+    expected_mint = pd.read_csv(os.path.join(data_dir, "expected_mint.csv")).drop(columns=TIME_COL)
+
+    # Input data and constraints
+    dl = DataLoader()
+    actuals = dl.load_data(data_name="daily_hierarchical_actuals").drop(columns=TIME_COL)
+    forecasts = dl.load_data(data_name="daily_hierarchical_forecasts").drop(columns=TIME_COL)
+    levels = [[2], [3, 2]]
+
+    raf = ReconcileAdditiveForecasts()
+    raf.fit_transform(
+        forecasts=forecasts,
+        actuals=actuals,
+        levels=levels,
+        method="ols"
+    )
+    assert_equal(raf.adjusted_forecasts, expected_ols)
+    raf.fit_transform(
+        forecasts=forecasts,
+        actuals=actuals,
+        levels=levels,
+        method="mint_sample"
+    )
+    assert_equal(raf.adjusted_forecasts, expected_mint, rel=1e-4)
+
+
+def test_raf_plot_transform_matrix(data):
+    """Tests plot_transform_matrix"""
+    forecasts = data["forecasts"]
+    actuals = data["actuals"]
+    levels = data["levels"]
+
+    raf = ReconcileAdditiveForecasts()
+
+    with pytest.raises(NotFittedError, match="Must call `fit` first."):
+        raf.plot_transform_matrix()
+
+    raf.fit(forecasts=forecasts, actuals=actuals, levels=levels)
+    fig = raf.plot_transform_matrix()
+    assert_equal(fig.data[0].x, list(raf.forecasts.columns))
+    assert_equal(fig.data[0].y, list(raf.forecasts.columns))
+    assert_equal(fig.data[0].z, raf.transform_matrix)
+    assert fig.layout.coloraxis.cmax == 1.5
+    assert fig.layout.coloraxis.cmin == -1.5
+    assert fig.layout.xaxis.type == "category"
+    assert fig.layout.yaxis.type == "category"
+
+    # tests customization
+    fig2 = raf.plot_transform_matrix(color_continuous_scale="BrBG", zmin=-1, zmax=1, height=400, width=500)
+    assert fig2.layout.coloraxis.cmax == 1
+    assert fig2.layout.coloraxis.cmin == -1
+    assert fig2.layout.height == 400
+    assert fig2.layout.width == 500
+    assert fig2.layout.coloraxis.colorscale != fig.layout.coloraxis.colorscale
