@@ -23,7 +23,7 @@ from greykite.sklearn.estimator.silverkite_estimator import SilverkiteEstimator
 
 
 try:
-    import fbprophet  # noqa
+    import prophet  # noqa
 except ModuleNotFoundError:
     pass
 
@@ -772,8 +772,8 @@ def test_plot_components():
                f"{{'DUMMY'}}, plotting the rest." in record[0].message.args[0]
 
 
-@pytest.mark.skipif("fbprophet" not in sys.modules,
-                    reason="Module 'fbprophet' not installed, pytest for 'ProphetTemplate' skipped.")
+@pytest.mark.skipif("prophet" not in sys.modules,
+                    reason="Module 'prophet' not installed, pytest for 'ProphetTemplate' skipped.")
 def test_plot_components_prophet():
     X = pd.DataFrame({
         cst.TIME_COL: pd.date_range("2018-01-01", periods=10, freq="D"),
