@@ -15,8 +15,8 @@ from greykite.framework.templates.simple_silverkite_template_config import SILVE
 from greykite.framework.templates.simple_silverkite_template_config import SILVERKITE_FREQ
 from greykite.framework.templates.simple_silverkite_template_config import SILVERKITE_GR
 from greykite.framework.templates.simple_silverkite_template_config import SILVERKITE_HOL
+from greykite.framework.templates.simple_silverkite_template_config import SILVERKITE_MONTHLY
 from greykite.framework.templates.simple_silverkite_template_config import SILVERKITE_SEAS
-from greykite.framework.templates.simple_silverkite_template_config import SILVERKITE_WITH_AR
 from greykite.framework.templates.simple_silverkite_template_config import SILVERKITE_WSI
 from greykite.framework.templates.simple_silverkite_template_config import VALID_FREQ
 from greykite.framework.templates.simple_silverkite_template_config import SimpleSilverkiteTemplateConstants
@@ -68,7 +68,7 @@ def test_simple_silvekite_template_constants():
     assert constants.MULTI_TEMPLATES == MULTI_TEMPLATES
 
     assert constants.SILVERKITE == SILVERKITE
-    assert constants.SILVERKITE_WITH_AR == SILVERKITE_WITH_AR
+    assert constants.SILVERKITE_MONTHLY == SILVERKITE_MONTHLY
     assert constants.SILVERKITE_DAILY_1_CONFIG_1 == SILVERKITE_DAILY_1_CONFIG_1
     assert constants.SILVERKITE_DAILY_1_CONFIG_2 == SILVERKITE_DAILY_1_CONFIG_2
     assert constants.SILVERKITE_DAILY_1_CONFIG_3 == SILVERKITE_DAILY_1_CONFIG_3
